@@ -11,7 +11,7 @@ class DjangoPyPalMixin(object):
 	Injects the user settings into the resource.
 	"""
 	def __init__(self, user_id=SECURITY_USER_ID, security_password=SECURITY_PASSWORD, security_signature=SECURITY_SIGNATURE, application_id=APPLICATION_ID, sandbox=settings.DEBUG):
-		super(DjangoPyPalMixin, self).__init__(user_id, security_password, security_signature, application_id, sandbox)
+		super(DjangoPyPalMixin, self).__init__(user_id, security_password, security_signature, application_id, sandbox=sandbox)
 
 #
 # Mix the resources with the settings mixin.
